@@ -4,8 +4,7 @@
 */
 "use strict";
 
-const ReplaceSource = require("webpack-sources").ReplaceSource;
-const RawSource = require("webpack-sources").RawSource;
+const { RawSource, ReplaceSource } = require("webpack-sources");
 
 class DependenciesBlockVariable {
 	constructor(name, expression, dependencies) {
@@ -17,32 +16,33 @@ class DependenciesBlockVariable {
 	updateHash(hash) {
 		hash.update(this.name);
 		hash.update(this.expression);
-		this.dependencies.forEach(d => {
+		for (const d of this.dependencies) {
 			d.updateHash(hash);
-		});
+		}
 	}
 
-	expressionSource(dependencyTemplates, outputOptions, requestShortener) {
+	expressionSource(dependencyTemplates, runtimeTemplate) {
 		const source = new ReplaceSource(new RawSource(this.expression));
-		this.dependencies.forEach(dep => {
+		for (const dep of this.dependencies) {
 			const template = dependencyTemplates.get(dep.constructor);
-			if(!template) throw new Error(`No template for dependency: ${dep.constructor.name}`);
-			template.apply(dep, source, outputOptions, requestShortener, dependencyTemplates);
-		});
+			if (!template)
+				throw new Error(`No template for dependency: ${dep.constructor.name}`);
+			template.apply(dep, source, runtimeTemplate, dependencyTemplates);
+		}
 		return source;
 	}
 
 	disconnect() {
-		this.dependencies.forEach(d => {
+		for (const d of this.dependencies) {
 			d.disconnect();
-		});
+		}
 	}
 
 	hasDependencies(filter) {
-		if(filter) {
-			if(this.dependencies.some(filter)) return true;
+		if (filter) {
+			if (this.dependencies.some(filter)) return true;
 		} else {
-			if(this.dependencies.length > 0) return true;
+			if (this.dependencies.length > 0) return true;
 		}
 		return false;
 	}
