@@ -5,7 +5,7 @@
 "use strict";
 
 const WebpackError = require("./WebpackError");
-const cleanUp = require("./ErrorHelpers").cleanUp;
+const { cleanUp } = require("./ErrorHelpers");
 
 class ModuleError extends WebpackError {
 	constructor(module, err) {
@@ -13,9 +13,13 @@ class ModuleError extends WebpackError {
 
 		this.name = "ModuleError";
 		this.module = module;
-		this.message = err && typeof err === "object" && err.message ? err.message : err;
+		this.message =
+			err && typeof err === "object" && err.message ? err.message : err;
 		this.error = err;
-		this.details = err && typeof err === "object" && err.stack ? cleanUp(err.stack, this.message) : undefined;
+		this.details =
+			err && typeof err === "object" && err.stack
+				? cleanUp(err.stack, this.message)
+				: undefined;
 
 		Error.captureStackTrace(this, this.constructor);
 	}
