@@ -5,17 +5,14 @@
 "use strict";
 
 const Module = require("./Module");
-const OriginalSource = require("webpack-sources").OriginalSource;
-const RawSource = require("webpack-sources").RawSource;
+const { OriginalSource, RawSource } = require("webpack-sources");
 
 module.exports = class RawModule extends Module {
-
 	constructor(source, identifier, readableIdentifier) {
-		super();
+		super("javascript/dynamic", null);
 		this.sourceStr = source;
 		this.identifierStr = identifier || this.sourceStr;
 		this.readableIdentifierStr = readableIdentifier || this.identifierStr;
-		this.cacheable = true;
 		this.built = false;
 	}
 
@@ -36,15 +33,18 @@ module.exports = class RawModule extends Module {
 	}
 
 	build(options, compilations, resolver, fs, callback) {
-		this.builtTime = Date.now();
+		this.built = true;
+		this.buildMeta = {};
+		this.buildInfo = {
+			cacheable: true
+		};
 		callback();
 	}
 
 	source() {
-		if(this.useSourceMap)
+		if (this.useSourceMap)
 			return new OriginalSource(this.sourceStr, this.identifier());
-		else
-			return new RawSource(this.sourceStr);
+		else return new RawSource(this.sourceStr);
 	}
 
 	updateHash(hash) {
