@@ -13,16 +13,25 @@ class SingleEntryPlugin {
 	}
 
 	apply(compiler) {
-		compiler.plugin("compilation", (compilation, params) => {
-			const normalModuleFactory = params.normalModuleFactory;
+		compiler.hooks.compilation.tap(
+			"SingleEntryPlugin",
+			(compilation, { normalModuleFactory }) => {
+				compilation.dependencyFactories.set(
+					SingleEntryDependency,
+					normalModuleFactory
+				);
+			}
+		);
 
-			compilation.dependencyFactories.set(SingleEntryDependency, normalModuleFactory);
-		});
+		compiler.hooks.make.tapAsync(
+			"SingleEntryPlugin",
+			(compilation, callback) => {
+				const { entry, name, context } = this;
 
-		compiler.plugin("make", (compilation, callback) => {
-			const dep = SingleEntryPlugin.createDependency(this.entry, this.name);
-			compilation.addEntry(this.context, dep, this.name, callback);
-		});
+				const dep = SingleEntryPlugin.createDependency(entry, name);
+				compilation.addEntry(context, dep, name, callback);
+			}
+		);
 	}
 
 	static createDependency(entry, name) {
