@@ -13,10 +13,12 @@ function webpack(options, callback) {
 	new WebpackOptionsDefaulter().process(options);
 
 	const compiler = new Compiler();
-	compiler.options = options;
 	compiler.options = new WebpackOptionsApply().process(options, compiler);
-	new WebEnvironmentPlugin(options.inputFileSystem, options.outputFileSystem).apply(compiler);
-	if(callback) {
+	new WebEnvironmentPlugin(
+		options.inputFileSystem,
+		options.outputFileSystem
+	).apply(compiler);
+	if (callback) {
 		compiler.run(callback);
 	}
 	return compiler;
