@@ -3,10 +3,10 @@ import { aa as aa2, d } from "./root3";
 var root6 = require("./root6");
 
 it("should correctly tree shake star exports", function() {
-	aa.should.be.eql("aa");
-	aa2.should.be.eql("aa");
-	d.should.be.eql("d");
-	root6.should.be.eql({
+	expect(aa).toBe("aa");
+	expect(aa2).toBe("aa");
+	expect(d).toBe("d");
+	expect(root6).toEqual({
 		aa: "aa",
 		c: "c"
 	});
