@@ -7,10 +7,10 @@ it("should evaluate null", function() {
 if("shouldn't evaluate expression", function() {
 	var value = "";
 	var x = (value + "") ? "fail" : "ok";
-	x.should.be.eql("ok");
+	expect(x).toBe("ok");
 });
 
-it("should short-circut evaluating", function() {
+it("should short-circuit evaluating", function() {
 	var expr;
 	var a = false && expr ? require("fail") : require("./a");
 	var b = true || expr ? require("./a") : require("fail");
@@ -18,5 +18,5 @@ it("should short-circut evaluating", function() {
 
 it("should evaluate __dirname and __resourceQuery with replace and substr", function() {
 	var result = require("./resourceQuery/index?" + __dirname);
-	result.should.be.eql("?resourceQuery");
+	expect(result).toEqual("?resourceQuery");
 });
