@@ -9,7 +9,7 @@ it("should import into object shorthand", function() {
 		b,
 		c
 	};
-	o.should.be.eql({
+	expect(o).toEqual({
 		a: 123,
 		aa: 123,
 		b: 456,
@@ -18,4 +18,4 @@ it("should import into object shorthand", function() {
 			default: 456
 		}
 	});
-})
\ No newline at end of file
+})
