@@ -1,11 +1,11 @@
 it("should resolve loaders relative to require", function() {
 	var index = "index", test = "test";
-	require("./loaders/queryloader?query!!!!./node_modules/subcontent/" + index + ".js").should.be.eql({
+	expect(require("./loaders/queryloader?query!!!!./node_modules/subcontent/" + index + ".js")).toEqual({
 		resourceQuery: "",
 		query: "?query",
 		prev: "module.exports = \"error\";"
 	});
-	require("!./loaders/queryloader?query!./node_modules/subcontent/" + test + ".jade").should.be.eql({
+	expect(require("!./loaders/queryloader?query!./node_modules/subcontent/" + test + ".jade")).toEqual({
 		resourceQuery: "",
 		query: "?query",
 		prev: "xyz: abc"
