@@ -1,7 +1,7 @@
 import { module } from "./reexport";
 
 it("should have the correct values", function() {
-	module.should.be.eql({
+	expect(module).toEqual({
 		default: "default",
 		named: "named"
 	});
