@@ -1,5 +1,5 @@
 it("should escape require.context id correctly", function() {
 	var context = require.context("./folder");
-	context("./a").should.be.eql("a");
-	context.id.should.be.type("string");
+	expect(context("./a")).toBe("a");
+	expect(context.id).toBeTypeOf("string");
 });
