@@ -15,12 +15,12 @@ it("should include only one use strict per module", function() {
 		match = regExp.exec(source);
 	}
 
-	matches.should.be.eql([
-		"it(\"should include only one use strict per module\", function() {",
-		"Object.defineProperty(__webpack_exports__, \"__esModule\", { value: true });",
-		"Object.defineProperty(__webpack_exports__, \"__esModule\", { value: true });",
-		"Object.defineProperty(__webpack_exports__, \"__esModule\", { value: true });",
-		"Object.defineProperty(__webpack_exports__, \"__esModule\", { value: true });",
+	expect(matches).toEqual([
+		"__webpack_require__.r(__webpack_exports__);",
 		"/* unused harmony default export */ var _unused_webpack_default_export = (\"a\");",
+		"__webpack_require__.r(__webpack_exports__);",
+		"__webpack_require__.r(__webpack_exports__);",
+		"__webpack_require__.r(__webpack_exports__);",
+		"it(\"should include only one use strict per module\", function() {",
 	]);
 });
