@@ -1,32 +1,29 @@
-var should = require("should");
 import d from "../0-create-dll/d";
 import { x1, y2 } from "./e";
 import { x2, y1 } from "../0-create-dll/e";
 
 it("should load a module from dll", function() {
-	require("../0-create-dll/a").should.be.eql("a");
+	expect(require("../0-create-dll/a")).toBe("a");
 });
 
 it("should load an async module from dll", function(done) {
 	require("../0-create-dll/b")().then(function(c) {
-		c.should.be.eql({ default: "c" });
+		expect(c).toEqual({ default: "c" });
 		done();
 	}).catch(done);
 });
 
 it("should load an harmony module from dll (default export)", function() {
-	d.should.be.eql("d");
+	expect(d).toBe("d");
 });
 
 it("should load an harmony module from dll (star export)", function() {
-	x1.should.be.eql(123);
-	x2.should.be.eql(123);
-	y1.should.be.eql(456);
-	y2.should.be.eql(456);
+	expect(x1).toBe(123);
+	expect(x2).toBe(123);
+	expect(y1).toBe(456);
+	expect(y2).toBe(456);
 });
 
 it("should load a module with loader applied", function() {
-	require("../0-create-dll/g.abc.js").should.be.eql("number");
+	expect(require("../0-create-dll/g.abc.js")).toBe("number");
 });
-
-
