@@ -5,7 +5,7 @@ module.exports = {
 			TRUE: true,
 			FALSE: false,
 			UNDEFINED: undefined,
-			FUNCTION: function(a) {
+			FUNCTION: /* istanbul ignore next */ function(a) {
 				return a + 1;
 			},
 			CODE: "(1+2)",
@@ -13,7 +13,7 @@ module.exports = {
 			OBJECT: {
 				SUB: {
 					UNDEFINED: undefined,
-					FUNCTION: function(a) {
+					FUNCTION: /* istanbul ignore next */ function(a) {
 						return a + 1;
 					},
 					CODE: "(1+2)",
@@ -22,11 +22,11 @@ module.exports = {
 				}
 			},
 			"process.env.DEFINED_NESTED_KEY": 5,
-			"process.env.DEFINED_NESTED_KEY_STRING": "\"string\"",
+			"process.env.DEFINED_NESTED_KEY_STRING": '"string"',
 			"typeof wurst": "typeof suppe",
 			"typeof suppe": "typeof wurst",
-			"wurst": "suppe",
-			"suppe": "wurst",
+			wurst: "suppe",
+			suppe: "wurst"
 		})
 	]
 };
