@@ -6,13 +6,13 @@ it("should write relative paths to records", function() {
 	var fs = require("fs");
 	var path = require("path");
 	var content = fs.readFileSync(path.join(__dirname, "records.json"), "utf-8");
-	content.should.eql(`{
+	expect(content).toEqual(`{
   "modules": {
     "byIdentifier": {
-      "test.js": 0,
-      "ignored  pkgs/somepackage/foo": 1,
-      "external \\"fs\\"": 2,
-      "external \\"path\\"": 3
+      "external \\"path\\"": 0,
+      "external \\"fs\\"": 1,
+      "ignored  pkgs/somepackage/foo": 2,
+      "test.js": 3
     },
     "usedIds": {
       "0": 0,
@@ -25,10 +25,10 @@ it("should write relative paths to records", function() {
     "byName": {
       "main": 0
     },
-    "byBlocks": {},
-    "usedIds": {
-      "0": 0
-    }
+    "bySource": {},
+    "usedIds": [
+      0
+    ]
   }
 }`);
 });
