@@ -1,6 +1,6 @@
 module.exports = function(source) {
 	this.cacheable(false);
-	var idx = this.options.updateIndex;
+	var idx = this.updateIndex;
 	var items = source.split(/---+\r?\n/g);
 	return items[idx] || items[items.length - 1];
-}
\ No newline at end of file
+}
