@@ -1,6 +1,4 @@
 var webpack = require("../../../../");
 module.exports = {
-	plugins: [
-		new webpack.AutomaticPrefetchPlugin()
-	]
+	plugins: [new webpack.AutomaticPrefetchPlugin()]
 };
